/*
 * checkopts.c
 *
 * $Revision: 0.1c $
 * $Author: charlesb $
 *
 * Linux RMS Gateway Statistics Program/Log Parser
 *
 * Copyright (c) 2008 Charles Blackburn - AI4RI
 *
 * Questions or problems regarding this program can be emailed
 * to stormchaseruk at gmail dot com
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Revision History
 * ----------------
 * 
 * Version	Date		Author		Description
 * 0.1c		06/06/08	charlesb	Original modularisation
 *
 */

#include "rmsstats.h"

void CheckOptions(int argc, char *argv[]) {
	int c;							// Option index
	int i;

	// Check Options
	// Valid options are: 
	// -c [config file]					// Config filename 
	// --conf [config file]					// Config filename
	// -u [usercall]					// Users call name (only required if run from ax25d)
	// --user [usercall]					// Users call name (only required if run from ax25d)
	// -v							// verbose
	// --verbose						// verbose
	while (1)
    	{
		static struct option long_options[] = {
			// These options set a flag.
			// {"verbose", 	no_argument,		&verbose_flag, 	1},

			// These options don't set a flag. We distinguish them by their indices.
			{"c",    	required_argument, 	0, 		'c'}, 			// config file
			{"u",    	required_argument, 	0,		'u'},			// usercall
			{"v",    	no_argument, 		0,		'v'},			// verbose
			{"h",    	no_argument, 		0,		'h'},			// usage
			{0, 0, 0, 0}
		};
		// getopt_long stores the option index here.
		int option_index = 0;

		c = getopt_long (argc, argv, "vc:u:", long_options, &option_index);

		// Detect the end of the options.
		if (c == -1)
			break;
     
		switch (c) {
			case 0:
				// If this option set a flag, do nothing else now.
				if (long_options[option_index].flag != 0)	break;

				printf ("option %s", long_options[option_index].name);
				if (optarg)
					printf (" with arg (%s)\n", optarg);
					break;

			case 'v':
				printf ("Using Verbose\n");
				verbose_flag = 1;
				break;

			case 'c':
				if (verbose_flag) { printf ("option -c with value `%s'\n", optarg); }
				// Set configureation file name - Checking to see if it's not blank if it is then set to default
				if ((strcmp(optarg, "")) != 0) 
					sprintf(conffile, "%s", optarg);
				if (verbose_flag) printf("Conffile: %s\n", conffile);
				break;
     
			case 'u':
				if (verbose_flag) { printf ("option -u with value `%s'\n", optarg); }
				// Set usercall - if empty then ignore
				if ((strcmp(optarg, "")) != 0) 
					sprintf(usercall, "%s", optarg);
				break;

			// getopt_long already printed an error message. 
			case '?':
			case 'h':
				printf(svnid);
				printf("\nUSAGE: rmsstats --c [config file] --v --u [user to search for] --h(elp)\n");
				abort();
				break;
     
			default:
				abort ();
		}
	}

	// Instead of reporting `--verbose' we report the final status resulting from them
	if (verbose_flag)
		printf("Verbose flag is set\n");

	// Print any remaining command line arguments (not options).
	if (optind < argc) {
		printf ("non-option ARGV-elements: ");
		while (optind < argc)
			printf ("%s ", argv[optind++]);
		putchar ('\n');
	}

}
