/*
 * rmsstats.c
 *
 * $Revision: 0.1c $
 * $Author: charlesb $
 *
 * Linux RMS Gateway Statistics Program/Log Parser
 *
 * Copyright (c) 2008 Charles Blackburn - AI4RI
 *
 * Questions or problems regarding this program can be emailed
 * to stormchaseruk at gmail dot com
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Revision History
 * ----------------
 * 
 * Version	Date		Author		Description
 * 0.1b		06/13/08	charlesb	Original re-write from bash/perl scripts
 * 0.1c		06/06/08	charlesb	Modularised for ease
 *
 */

#include "rmsstats.h"

// define our variables that are extern in .h
float TotalTXBytes = 0.0;
float TotalRXBytes = 0.0;
float TotalTime = 0.0;
float TotalSpeed = 0.0;
unsigned int TotalConnects = 0;
unsigned int ErrorLines = 0;				// Total lines which are Error'd
unsigned int TotalLines = 0;				// Total Lines of Logouts that are valid
unsigned int days, hours, minutes, seconds = 0;
char conffile[50] = DEFLOG;
char usercall[10] = "";
int verbose_flag = 0;

int main(int argc, char *argv[])
{
	char buffer[255];

	FILE *fp;						// file pointer

	// Check the command line Options
	CheckOptions(argc, argv);
	
	if (verbose_flag) printf("MAIN: Using Configuration File: %s\n", conffile);
	if ((verbose_flag) && ((strcmp(usercall, "")) != 0)) printf("Looking for user-call: %s\n", usercall);

	if ((fp=OpenConfig(conffile))==NULL) {
		abort();
    	}

	// start reading and parsing logfile
	char call[10];
	unsigned int txbytes, rxbytes;
	float ttime = 0.0;
	float speed = 0.0;
	char *syslog_data = NULL;

	// start reading and parsing logfile
	while (!feof(fp)) {
		// read a line
		fgets((char *)buffer, 254, fp);

		// need to remove any \n and replace it with a \0 (null terminator)
		// strlen(buffer) will return number of bytes read. so change the n-1 byte to \o
		if (buffer[((strlen(buffer))-1)] = '\n') 
			buffer[((strlen(buffer))-1)] = '\0';
		
		// We only want the logout lines and only those which aren't in ERROR
		// but we're going to count those anyways.
		// and example of what we want is:
		// Jun  2 19:19:22 GOKIT rmsgw[6372]: Logout AI4RI     tx:71 rx:2787 150.0s 19.1 Bytes/s (0)
		// result contains the actual text of the syslog minus all the date/time/process crap
		// which we don't need.
		if ((syslog_data = strstr(buffer, "Logout")) != NULL) {
			sscanf(syslog_data, "Logout %s tx:%d rx:%d %fs %f Bytes/s (0)", call, &txbytes, &rxbytes, &ttime, &speed);

			// If Verbose is set then print out lines as processed
			if (verbose_flag) {
				printf("Buffer: %s\n", buffer);
				printf("CALL: %s - TX Bytes:%d - RX Bytes: %d - Time: %fs - Speed: %f Bytes/s\n", call, txbytes, rxbytes, ttime, speed);
			}

			if ((strstr(call, ERRORSTR)) != NULL) {
				ErrorLines++;
			} else {
				// ok here we can check ONLY for specific calls
				if ((strcmp(usercall, "")) != 0) {				// if non-zero then we're checking for a call 
					if ((strcmp(call, tucase(usercall))) == 0) {		
						// Tot um up
						if (verbose_flag) printf("USERCALL found: %s\n", call);
						TotalUp(call, txbytes, rxbytes, ttime, speed);
					}
				} else {
					// Tot um up
					TotalUp(call, txbytes, rxbytes, ttime, speed);
				}
			}
		}
	}

	fclose(fp);

	unsigned int days, hours, minutes, seconds;

	days = TotalTime / 864000;
	hours = (TotalTime / 3600) - (days * 24);
	minutes = (TotalTime / 60) - (days * 1440) - (hours * 60);
	seconds = (int)TotalTime % 60;

	// OK we've processed the log file lets wait for the link to settle down
	sleep(1);

	// Print results
	printf(" %s\n", svnid);
	sleep(1);
	printf(" (c) Copyright 2008, Charles Blackburn - AI4RI (conf: %s)\n", conffile);
	sleep(1);
	printf(" Total Connects: %d, Total ERRORS: %d\n", TotalLines, ErrorLines);
	sleep(1);
	printf(" Total In: %.2f Kbytes, Total Out: %.2f KBytes\n", (TotalRXBytes/1024), (TotalTXBytes/1024));
	sleep(1);
	printf(" Total Time: %d Days, %02d:%02d:%02d", days, hours, minutes, seconds);
	sleep(1);
	printf(" with an average speed: %.2f bytes/s\n", (TotalRXBytes + TotalTXBytes) / TotalTime);
	sleep(1);
	return 0;
}

char *tucase(char str[]) {
	char *ptr = NULL; 
	ptr = str; 

	for(ptr=str;*ptr;ptr++) {
	 
		*ptr=toupper(*ptr); 
	}
	return((char *)str);
}
